summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--extra/yassl/src/ssl.cpp2
-rw-r--r--mysql-test/r/mysqld--help.result2
-rw-r--r--mysql-test/suite/plugins/r/locales.result8
-rw-r--r--pcre/testdata/greppatN42
-rw-r--r--sql/mysqld.cc4
-rw-r--r--sql/sql_locale.cc8
-rw-r--r--storage/spider/spd_param.cc2
7 files changed, 14 insertions, 14 deletions
diff --git a/extra/yassl/src/ssl.cpp b/extra/yassl/src/ssl.cpp
index 356b310037e..111da306b4d 100644
--- a/extra/yassl/src/ssl.cpp
+++ b/extra/yassl/src/ssl.cpp
@@ -952,7 +952,7 @@ void OpenSSL_add_all_algorithms() // compatibility only
{}
-int SSL_library_init() // compatiblity only
+int SSL_library_init() // compatibility only
{
return 1;
}
diff --git a/mysql-test/r/mysqld--help.result b/mysql-test/r/mysqld--help.result
index fc22af6b9be..e4444205940 100644
--- a/mysql-test/r/mysqld--help.result
+++ b/mysql-test/r/mysqld--help.result
@@ -898,7 +898,7 @@ The following options may be given as the first argument:
--show-slave-auth-info
Show user and password in SHOW SLAVE HOSTS on this
master.
- --skip-bdb Deprecated option; Exist only for compatiblity with old
+ --skip-bdb Deprecated option; Exist only for compatibility with old
my.cnf files
--skip-grant-tables Start without grant tables. This gives all users FULL
ACCESS to all tables.
diff --git a/mysql-test/suite/plugins/r/locales.result b/mysql-test/suite/plugins/r/locales.result
index 3ff43a3244c..881f91e0ac5 100644
--- a/mysql-test/suite/plugins/r/locales.result
+++ b/mysql-test/suite/plugins/r/locales.result
@@ -40,8 +40,8 @@ ID NAME DESCRIPTION MAX_MONTH_NAME_LENGTH MAX_DAY_NAME_LENGTH DECIMAL_POINT THOU
37 nb_NO Norwegian(Bokml) - Norway 9 7 , . norwegian
38 nl_NL Dutch - The Netherlands 9 9 , dutch
39 pl_PL Polish - Poland 11 12 , polish
-40 pt_BR Portugese - Brazil 9 7 , portuguese
-41 pt_PT Portugese - Portugal 9 7 , portuguese
+40 pt_BR Portuguese - Brazil 9 7 , portuguese
+41 pt_PT Portuguese - Portugal 9 7 , portuguese
42 ro_RO Romanian - Romania 10 8 , . romanian
43 ru_RU Russian - Russia 8 11 , russian
44 ru_UA Russian - Ukraine 8 11 , . russian
@@ -153,8 +153,8 @@ Id Name Description Error_Message_Language
37 nb_NO Norwegian(Bokml) - Norway norwegian
38 nl_NL Dutch - The Netherlands dutch
39 pl_PL Polish - Poland polish
-40 pt_BR Portugese - Brazil portuguese
-41 pt_PT Portugese - Portugal portuguese
+40 pt_BR Portuguese - Brazil portuguese
+41 pt_PT Portuguese - Portugal portuguese
42 ro_RO Romanian - Romania romanian
43 ru_RU Russian - Russia russian
44 ru_UA Russian - Ukraine russian
diff --git a/pcre/testdata/greppatN4 b/pcre/testdata/greppatN4
index ea1bfc78ac4..7112d84fa15 100644
--- a/pcre/testdata/greppatN4
+++ b/pcre/testdata/greppatN4
@@ -1,2 +1,2 @@
-xxx
+xxx
jkl \ No newline at end of file
diff --git a/sql/mysqld.cc b/sql/mysqld.cc
index 9a71407730c..cd87d8fc340 100644
--- a/sql/mysqld.cc
+++ b/sql/mysqld.cc
@@ -7414,7 +7414,7 @@ struct my_option my_long_options[]=
&opt_show_slave_auth_info, &opt_show_slave_auth_info, 0,
GET_BOOL, NO_ARG, 0, 0, 0, 0, 0, 0},
{"skip-bdb", OPT_DEPRECATED_OPTION,
- "Deprecated option; Exist only for compatiblity with old my.cnf files",
+ "Deprecated option; Exist only for compatibility with old my.cnf files",
0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0},
#ifndef DISABLE_GRANT_OPTIONS
{"skip-grant-tables", 0,
@@ -8799,7 +8799,7 @@ mysqld_get_one_option(int optid, const struct my_option *opt, char *argument)
break;
case OPT_DEPRECATED_OPTION:
sql_print_warning("'%s' is deprecated. It does nothing and exists only "
- "for compatiblity with old my.cnf files.",
+ "for compatibility with old my.cnf files.",
opt->name);
break;
case OPT_MYSQL_COMPATIBILITY:
diff --git a/storage/spider/spd_param.cc b/storage/spider/spd_param.cc
index 7376bfc0499..6d7baa8a584 100644
--- a/storage/spider/spd_param.cc
+++ b/storage/spider/spd_param.cc
@@ -1859,7 +1859,7 @@ int spider_param_auto_increment_mode(
static MYSQL_THDVAR_BOOL(
same_server_link, /* name */
PLUGIN_VAR_OPCMDARG, /* opt */
- "Permit to link same server's table", /* comment */
+ "Permit one to link same server's table", /* comment */
NULL, /* check */
NULL, /* update */
FALSE /* def */
diff --git a/sql/sql_locale.cc b/sql/sql_locale.cc
index bdda5f1b5ef..5ac069de98b 100644
--- a/sql/sql_locale.cc
+++ b/sql/sql_locale.cc
@@ -1433,7 +1433,7 @@ MY_LOCALE my_locale_pl_PL
);
/***** LOCALE END pl_PL *****/
/***** LOCALE BEGIN pt_BR: Portugese - Brazil *****/
static const char *my_locale_month_names_pt_BR[13] =
{"janeiro","fevereiro","março","abril","maio","junho","julho","agosto","setembro","outubro","novembro","dezembro", NullS };
static const char *my_locale_ab_month_names_pt_BR[13] =
@@ -1454,7 +1454,7 @@ MY_LOCALE my_locale_pt_BR
(
40,
"pt_BR",
- "Portugese - Brazil",
+ "Portuguese - Brazil",
FALSE,
&my_locale_typelib_month_names_pt_BR,
&my_locale_typelib_ab_month_names_pt_BR,
@@ -1469,7 +1469,7 @@ MY_LOCALE my_locale_pt_BR
);
/***** LOCALE END pt_BR *****/
/***** LOCALE BEGIN pt_PT: Portugese - Portugal *****/
static const char *my_locale_month_names_pt_PT[13] =
{"Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro", NullS };
static const char *my_locale_ab_month_names_pt_PT[13] =
@@ -1490,7 +1490,7 @@ MY_LOCALE my_locale_pt_PT
(
41,
"pt_PT",
- "Portugese - Portugal",
+ "Portuguese - Portugal",
FALSE,
&my_locale_typelib_month_names_pt_PT,
&my_locale_typelib_ab_month_names_pt_PT,
@@ -1433,7 +1433,7 @@ MY_LOCALE my_locale_pl_PL
);
/***** LOCALE END pl_PL *****/
-/***** LOCALE BEGIN pt_BR: Portugese - Brazil *****/
+/***** LOCALE BEGIN pt_BR: Portuguese - Brazil *****/
static const char *my_locale_month_names_pt_BR[13] =
{"janeiro","fevereiro","março","abril","maio","junho","julho","agosto","setembro","outubro","novembro","dezembro", NullS };
@@ -1469,7 +1469,7 @@ MY_LOCALE my_locale_pt_BR
);
/***** LOCALE END pt_BR *****/
-/***** LOCALE BEGIN pt_PT: Portugese - Portugal *****/
+/***** LOCALE BEGIN pt_PT: Portuguese - Portugal *****/
static const char *my_locale_month_names_pt_PT[13] =
{"Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro", NullS };